@@ -124,7 +124,7 @@ int yk_check_firmware_version2(YK_STATUS *st)
 				return 1;
 			break;
 		case 4:
-			if(st->versionMinor <= 1)
+			if(st->versionMinor <= 2)
 				return 1;
 			break;
 	}
@@ -234,7 +234,8 @@ static int _yk_write(YK_KEY *yk, uint8_t yk_cmd, unsigned char *buf, size_t len)
 	 * want to get the bytes in the status message, but when writing configuration
 	 * we don't expect any data back.
 	 */
-	yk_wait_for_key_status(yk, yk_cmd, 0, WAIT_FOR_WRITE_FLAG, false, SLOT_WRITE_FLAG, NULL);
+	if(!yk_wait_for_key_status(yk, yk_cmd, 0, WAIT_FOR_WRITE_FLAG, false, SLOT_WRITE_FLAG, NULL))
+		return 0;
 
 	/* Verify update */
 
@@ -677,12 +678,6 @@ int yk_write_to_key(YK_KEY *yk, uint8_t slot, const void *buf, int bufcount)
 	ptr = (unsigned char *) &frame;
 	end = (unsigned char *) &frame + sizeof(frame);
 
-	/* Initial check that the YubiKey is in a state where it will accept
-	 * a write.
-	 *
-	if (! yk_wait_for_key_status(yk, slot, 0, 1000, false, SLOT_WRITE_FLAG, NULL))
-		return 0;
-	*/
 #ifdef YK_DEBUG
 	fprintf(stderr, "YK_DEBUG: Write %i bytes to YubiKey :\n", bufcount);
 #endif
