@@ -205,6 +205,14 @@ int _ykusb_close_device(void *yk)
 	return 0;
 }
 
+int _ykusb_get_vid_pid(void *yk, int *vid, int *pid) {
+	struct usb_dev_handle *h = yk;
+	struct usb_device *dev = usb_device(h);
+	*vid = dev->descriptor.idVendor;
+	*pid = dev->descriptor.idProduct;
+	return 1;
+}
+
 const char *_ykusb_strerror(void)
 {
 	return usb_strerror();
